#ifndef MainWindow_h
#define MainWindow_h

#include "YumIO.h"
#include <QMainWindow>
#include <QLineEdit>
#include <QIcon>
#include <QComboBox>
#include <QPushButton>
#include <QCheckBox>
#include "HMenu.h"
#include "HFrameLabel.h"
#include <QAction>
#include "PackageTableView.h"
#include "RepoEditorDialog.h"
#include "LogWindow.h"
#include "YumConfIO.h"
#include "YumReposEnabled.h"
#include "YumReposUsed.h"

class MainWindow : public QMainWindow {
   Q_OBJECT
public:
   explicit MainWindow(QWidget*  parent);
public:
   void setVisible(bool  visible);
public:
   void setMode(PackageTable::Mode  mode);
   void setRegexp(const char*  regexp);
   void setStateFilter(PackageTable::StateFilter  sf);
   void setDups(bool  d);
   void setGroups(bool  g);
   void setReady(bool  ready);
public slots:
   void resize();
   void refresh();
   void reposChanged();
protected slots:
   void initialize();
   void yumConfIOChanged();
   void quit();
   void displayLog();
   void editRepositories(bool  forceReposChanged = false);
   void cleanDbcache();
   void cleanPackages();
   void cleanMetadata();
   void cleanAll();
   void manualHtml();
   void manualPdf();
   void about();
   void filtersearch();
   void currentChanged      (int  currentRow,
                             int  previousRow);
   void stateChanged        (int  row = -1);
   void modeChanged         (int  index);
   void collectedExtraData  ();
   void stateFilterChanged  (int  index);
   void dupsFilterChanged   (int  checked);
   void groupsFilterChanged (int  checked);
   void setSelected();
   void setUpdateListed();
   void clearActions();
   void apply();
protected:
   void anyFilterChanged();
   void warnConfigure();
   void warnUnlistedActions();
   void prepareFilterSearch();
protected:
   QSize sizeHint() const;
protected:
   void createMenuBar();
   void createMainArea();
protected:
   QIcon  updateAllIcon;
   QIcon  clearIcon;
   QIcon  checkIcon;
public:
   bool                                 optRepoEditor;
   bool                                 optLog;
   YumReposEnabled                      yumReposEnabled;
protected:
   YumReposUsed                         yumReposUsed;
   YumIO*                               yumIO;
   YumConfIO*                           yumConfIO;
protected:
   bool                                 initialized;
   HMenu*                               programMenu;
   QAction*                             quitAction;
   HMenu*                               repoMenu;
   QAction*                             editAction;
   HMenu*                               cacheMenu;
   QAction*                             cleanDbcacheAction;
   QAction*                             cleanPackagesAction;
   QAction*                             cleanMetadataAction;
   QAction*                             cleanAllAction;
   QWidget*                             packageTableConfig;
   QComboBox*                           modeComboBox;
   QLineEdit*                           controlEdit;
   QPushButton*                         controlButton;
   QComboBox*                           stateComboBox;
   QCheckBox*                           groupsCheckBox;
   QCheckBox*                           dupsCheckBox;
   PackageTable::Model*                 packageTableModel;
   PackageTable::SortFilterProxyModel*  packageTableSortedModel;
   PackageTable::View*                  packageTableView;
   QPushButton*                         describeButton;
   HFrameLabel*                         warningLabel;
   QPushButton*                         applyButton;
protected:
   RepoEditor::Dialog*  repoEditorDialog;
   Log::Window*         logWindow;
};

#endif
